""" Tests that we can receive information about different submission types """

from django.urls import reverse
from rest_framework import status
from rest_framework.test import (APIRequestFactory, APITestCase,
                                 force_authenticate)

from core.models import SubmissionType
from core.views import SubmissionTypeApiView
from util.factories import GradyUserFactory


class SubmissionTypeViewTest(APITestCase):

    @classmethod
    def setUpTestData(cls):
        cls.factory = APIRequestFactory()
        cls.user_factory = GradyUserFactory()

    def setUp(self):
        self.request = self.factory.get(reverse('submissiontype-list'))
        SubmissionType.objects.create(name='Hard question',
                                      full_score=20,
                                      description='Whatever')
        force_authenticate(self.request,
                           self.user_factory.make_reviewer().user)
        self.view = SubmissionTypeApiView.as_view({'get': 'list'})
        self.response = self.view(self.request)

    def test_can_access_when_authenticated(self):
        self.assertEqual(self.response.status_code, status.HTTP_200_OK)

    def test_get_all_available_submissiontypes(self):
        self.assertEqual(1, len(self.response.data))

    def test_get_sumbission_type_name(self):
        self.assertEqual('Hard question', self.response.data[0]['name'])

    def test_get_full_score(self):
        self.assertEqual(20, self.response.data[0]['full_score'])

    def test_get_descritpion(self):
        self.assertEqual('Whatever', self.response.data[0]['description'])

    def test_there_is_no_solution_to_nothing(self):
        self.assertEqual('', self.response.data[0]['solution'])
